#ifndef TRACKLAUNCHER_H
#define TRACKLAUNCHER_H

#include <QObject>
#include <QUrl>

class TrackLauncher : public QObject
{
    Q_OBJECT

public:
    explicit TrackLauncher(QObject *parent = 0);
    ~TrackLauncher();

    static TrackLauncher* instance();
    
public slots:
    static void launchTrack(const QUrl &url);
    static void launchTracks(QList<QUrl> &urls);

private:
    static TrackLauncher* m_instance;
};

#endif // TRACKLAUNCHER_H
